bayespy.inference.vmp.nodes.gaussian.GaussianGammaISOToGaussianGammaARD.__init__
================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaISOToGaussianGammaARD.__init__